<?php

if (!defined('ABSPATH')) {
    exit;
}

class Evdpl_Cookie_Consent_Policy_Generator_Ajax extends Evdpl_Cookie_Consent_Cli_Policy_Generator {

    public function __construct() {
        add_action('wp_ajax_ecc_policy_generator', array($this, 'ecc_ajax_policy_generator'));
    }

    /*
     *
     * Main Ajax hook for processing requests
     */

    public function ecc_ajax_policy_generator() {
        check_ajax_referer('ecc_policy_generator', 'security');
        if (!current_user_can('manage_options')) {
            wp_die(__('You do not have sufficient permission to perform this operation', 'evdpl-cookie-consent'));
        }
        $out = array(
            'response' => false,
            'message' => __('Unable to handle your request.', 'evdpl-cookie-consent'),
        );
        $non_json_response = array();
        if (isset($_POST['ecc_policy_generator_action'])) {
            $allowed_actions = array('ecc_autosave_contant_data', 'ecc_save_contentdata', 'ecc_get_policy_pageid');
            $ecc_policy_generator_action = isset($_POST['ecc_policy_generator_action']) && in_array($_POST['ecc_policy_generator_action'], $allowed_actions) ? sanitize_text_field($_POST['ecc_policy_generator_action']) : '';
            if (in_array($ecc_policy_generator_action, $allowed_actions) && method_exists($this, $ecc_policy_generator_action)) {
                $out = $this->{$ecc_policy_generator_action}();
            }
        }
        if (in_array($ecc_policy_generator_action, $non_json_response)) {
            echo is_array($out) ? esc_attr($out['message']) : esc_attr($out);
        } else {
            echo esc_attr(json_encode($out));
        }
        exit();
    }

    /*
     * 	@since 1.0
     * 	Get current policy page ID (Ajax-main)
     * 	This is used to update the hidden field for policy page id. (In some case user press back button)
     */

    public function ecc_get_policy_pageid() {
        $page_id = Evdpl_Cookie_Consent_Cli_Policy_Generator::ecc_get_cookie_policy_pageid();
        $policy_page_status = get_post_status($page_id);
        if ($policy_page_status && $policy_page_status != 'trash') {
            
        } else {
            $page_id = 0;
        }
        return array(
            'response' => true,
            'page_id' => $page_id,
        );
    }

    /*
     * 	@since 1.0
     * 	Save current data (Ajax-main)
     */

    public function ecc_save_contentdata() {
        $out = array(
            'response' => true,
            'er' => ''
        );
        $content_data = isset($_POST['content_data']) ? is_array($_POST['content_data']) ? array_map('sanitize_text_field',$_POST['content_data']) : sanitize_text_field($_POST['content_data']) : array();
        $page_id = (int) isset($_POST['page_id']) ? sanitize_text_field($_POST['page_id']) : 0;
        $enable_evince_powered_by = (int) isset($_POST['enable_evince_powered_by']) ? sanitize_text_field($_POST['enable_evince_powered_by']) : 0;
        $id = wp_insert_post(
                array(
                    'ID' => $page_id, //if ID is zero it will create new page otherwise update
                    'post_title' => 'Cookie Policy',
                    'post_type' => 'page',
                    'post_content' => Evdpl_Cookie_Consent_Cli_Policy_Generator::ecc_generate_page_content($enable_evince_powered_by, $content_data, 0),
                    'post_status' => 'draft', //default is draft
                )
        );
        if (is_wp_error($id)) {
            $out = array(
                'response' => false,
                'er' => __('Error', 'evdpl-cookie-consent'),
                    //'er'=>$id->get_error_message(),
            );
        } else {
            Evdpl_Cookie_Consent_Cli_Policy_Generator::ecc_set_cookie_policy_pageid($id);
            $out['url'] = get_edit_post_link($id);
        }
        return $out;
    }

    /*
     * 	@since 1.0
     * 	Autosave Current content to session (Ajax-main)
     */

    public function ecc_autosave_contant_data() {
        $out = array(
            'response' => true,
            'er' => ''
        );
        $content_data = isset($_POST['content_data']) ? is_array($_POST['content_data']) ? array_map('sanitize_text_field',$_POST['content_data']) : sanitize_text_field($_POST['content_data']) : array();
        $page_id = (int) isset($_POST['page_id']) ? sanitize_text_field($_POST['page_id']) : '';
        $enable_evince_powered_by = (int) isset($_POST['enable_evince_powered_by']) ? sanitize_text_field($_POST['enable_evince_powered_by']) : 0;
        if (is_array($content_data)) {
            $content_html = Evdpl_Cookie_Consent_Cli_Policy_Generator::ecc_generate_page_content($enable_evince_powered_by, $content_data);
            update_option('ecc_pg_content_data', $content_html);
        } else {
            $out = array(
                'response' => false,
                'er' => __('Error', 'evdpl-cookie-consent')
            );
        }
        return $out;
    }

}

new Evdpl_Cookie_Consent_Policy_Generator_Ajax();
