<?php
/**
 * @wordpress-plugin
 * Plugin Name: GDPR/CCPA Cookie Consent & Compliance
 * Plugin URI: https://wordpress.org/plugins/gdpr-ccpa-cookie-consent/
 * Description: A simple way to show your website complies with the EU Cookie Law / GDPR.
 * Version: 1.0
 * Author: EvinceDev
 * Author URI: https://evincedev.com/
 * Text Domain: evdpl-cookie-consent
 * Domain Path: /languages
 * License: GPLv3 or later
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

$wt_ecc_wp_lanugage = get_option( 'WPLANG', 'en_US' );
if ( empty( $wt_ecc_wp_lanugage ) || strlen( $wt_ecc_wp_lanugage ) <= 1 ) {
	$wt_ecc_wp_lanugage = 'en';
}
define( 'ECC_PLUGIN_DEVELOPMENT_MODE', false );
define( 'ECC_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
define( 'ECC_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
define( 'ECC_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
define( 'ECC_DB_KEY_PREFIX', 'EvdplCookieinfo-' );
define( 'ECC_LATEST_VERSION_NUMBER', '0.9' );
define( 'ECC_SETTINGS_FIELD', ECC_DB_KEY_PREFIX . ECC_LATEST_VERSION_NUMBER );
define( 'ECC_MIGRATED_VERSION', ECC_DB_KEY_PREFIX . 'MigratedVersion' );
// Previous version settings (depreciated from 0.1 onwards):
define( 'ECC_ADMIN_OPTIONS_NAME', 'EvdplCookieinfo-0.8.3' );
define( 'ECC_PLUGIN_FILENAME', __FILE__ );
define( 'ECC_POST_TYPE', 'evdplcookieinfo' );
define( 'ECC_DEFAULT_LANGUAGE', substr( $wt_ecc_wp_lanugage, 0, 2 ) );
define( 'ECC_ACTIVATION_ID', 'wtgdprcookieconsent' );

/**
 * Currently plugin version.
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'ECC_VERSION', '1.0' );

function wt_evdpl_cookie_consent_update_message( $data, $response ) {
	if ( isset( $data['upgrade_notice'] ) ) {
		add_action( 'admin_print_footer_scripts', 'wt_evdpl_cookie_consent_plugin_screen_update_js' );
		$msg = str_replace( array( '<p>', '</p>' ), array( '<div>', '</div>' ), $data['upgrade_notice'] );
		echo '<style type="text/css">
        #evdpl-cookie-consent-update .update-message p:last-child{ display:none;}     
        #evdpl-cookie-consent-update ul{ list-style:disc; margin-left:30px;}
        .wf-update-message{ padding-left:30px;}
        </style>
        <div class="update-message wf-update-message"><div style="color: #f56e28;">' . __( 'Please make sure the cache is cleared after each plugin update especially if you have minified JS and/or CSS files.', 'evdpl-cookie-consent' ) . '</div>' . wpautop( $msg ) . '</div>';
	}
}
function wt_evdpl_cookie_consent_plugin_screen_update_js() {     ?>
		<script>
			( function( $ ){
				var update_dv=$( '#evdpl-cookie-consent-update ');
				update_dv.find('.wf-update-message').next('p').remove();
				update_dv.find('a.update-link:eq(0)').click(function(){
					$('.wf-update-message').remove();
				});
			})( jQuery );
		</script>
		<?php
}
add_action( 'in_plugin_update_message-evdpl-cookie-consent/evdpl-cookie-consent.php', 'wt_evdpl_cookie_consent_update_message', 10, 2 );
/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-evdpl-cookie-consent-activator.php
 */
require_once plugin_dir_path( __FILE__ ) . 'includes/class-evdpl-cookie-consent-activator.php';
function activate_evdpl_cookie_consent() {
	Evdpl_Cookie_Consent_Activator::activate();
	register_uninstall_hook( __FILE__, 'uninstall_evdpl_cookie_consent' );
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-evdpl-cookie-consent-deactivator.php
 */
function deactivate_evdpl_cookie_consent() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-evdpl-cookie-consent-deactivator.php';
	Evdpl_Cookie_Consent_Deactivator::deactivate();
}
register_activation_hook( __FILE__, 'activate_evdpl_cookie_consent' );
register_deactivation_hook( __FILE__, 'deactivate_evdpl_cookie_consent' );


function uninstall_evdpl_cookie_consent() {
	// Bye bye settings:
	delete_option( ECC_ADMIN_OPTIONS_NAME );
	delete_option( ECC_MIGRATED_VERSION );
	delete_option( ECC_SETTINGS_FIELD );

	// Bye bye custom meta:
	$args  = array( 'post_type' => 'evdplcookieinfo' );
	$posts = get_posts( $args );
	if ( ! $posts ) {
		return;
	}
	if ( $posts ) {
		foreach ( $posts as $post ) {
			$custom = get_post_custom( $post->ID );
			// Look for old values. If they exist, move them to new values then delete old values:
			if ( isset( $custom['cookie_type'][0] ) ) {
				delete_post_meta( $post->ID, 'cookie_type', $custom['cookie_type'][0] );
			}
			if ( isset( $custom['cookie_duration'][0] ) ) {
				delete_post_meta( $post->ID, 'cookie_duration', $custom['cookie_duration'][0] );
			}
			if ( isset( $custom['_ecc_cookie_type'][0] ) ) {
				delete_post_meta( $post->ID, '_ecc_cookie_type', $custom['_ecc_cookie_type'][0] );
			}
			if ( isset( $custom['_ecc_cookie_duration'][0] ) ) {
				delete_post_meta( $post->ID, '_ecc_cookie_duration', $custom['_ecc_cookie_duration'][0] );
			}
		}
	}
}



/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-evdpl-cookie-consent.php';


/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0
 */
function run_evdpl_cookie_consent() {

	$plugin = new Evdpl_Cookie_Consent();
	$plugin->run();
}
run_evdpl_cookie_consent();
