<?php

/**
 * Fired during plugin activation
 *
 * @link       http://evdplcookieinfo.com/
 * @since      1.0
 *
 * @package    Evdpl_Cookie_Consent
 * @subpackage Evdpl_Cookie_Consent/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0
 * @package    Evdpl_Cookie_Consent
 * @subpackage Evdpl_Cookie_Consent/includes
 * @author     Evincedev
 */
class Evdpl_Cookie_Consent_Activator {

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0
	 */
	private static $db_updates = array(
		'1.0' => array(
			'ecc_wt_ecc_update_db_version',
		),
	);

	public static function init() {
		add_action( 'init', array( __CLASS__, 'ecc_check_version' ), 5 );
	}

	public static function activate() {
		 global $wpdb;
		require_once ABSPATH . 'wp-admin/includes/upgrade.php';
		Evdpl_Cookie_Consent::ecc_check_for_upgrade();

		if ( is_multisite() ) {
			// Get all blogs in the network and activate plugin on each one
			$blog_ids = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
			foreach ( $blog_ids as $blog_id ) {
				switch_to_blog( $blog_id );
				self::ecc_install_tables();
				Evdpl_Cookie_Consent::ecc_patches();
				restore_current_blog();
			}
		} else {
			self::ecc_install_tables();
			Evdpl_Cookie_Consent::ecc_patches();
		}

	}
	public static function ecc_install_tables() {
		global $wpdb;
		// install necessary tables
	}
	public static function ecc_needs_db_update() {
		$current_db_version = get_option( 'wt_ecc_db_version', Evdpl_Cookie_Consent::$db_initial_version ); // @since 1.9.6 introduced DB migrations
		$updates            = self::ecc_get_db_update_callbacks();
		$update_versions    = array_keys( $updates );
		usort( $update_versions, 'version_compare' );

		return ! is_null( $current_db_version ) && version_compare( $current_db_version, end( $update_versions ), '<' );
	}

	public static function ecc_get_db_update_callbacks() {
		return self::$db_updates;
	}

	public static function ecc_update_db_version( $version = null ) {
		update_option( 'wt_ecc_db_version', is_null( $version ) ? ECC_VERSION : $version );
	}

	private static function ecc_maybe_update_db_version() {

		if ( self::ecc_needs_db_update() ) {
			self::update();
		} else {
			self::ecc_update_db_version(); // First time install
		}
	}

	private static function update() {
		$current_db_version = get_option( 'wt_ecc_db_version', Evdpl_Cookie_Consent::$db_initial_version );

		foreach ( self::ecc_get_db_update_callbacks() as $version => $update_callbacks ) {

			if ( version_compare( $current_db_version, $version, '<' ) ) {
				foreach ( $update_callbacks as $update_callback ) {
					self::$update_callback();
				}
			}
		}
	}

	private static function ecc_wt_ecc_update_db_version() {
		self::ecc_update_cookie_db_version( '1.0' );
		self::ecc_update_db_version();
	}
	/**
	 * Check the plugin version and run the updater is required.
	 *
	 * This check is done on all requests and runs if the versions do not match.
	 */
	public static function ecc_check_version() {
		if ( ! defined( 'IFRAME_REQUEST' ) && version_compare( get_option( 'wt_ecc_version', '1.9.5' ), ECC_VERSION, '<' ) ) {
			self::ecc_install();
		}
	}
	private static function ecc_update_plugin_version() {
		update_option( 'wt_ecc_version', ECC_VERSION );
	}
	public static function ecc_install() {
		self::ecc_maybe_update_db_version();
		self::ecc_update_plugin_version();
	}
	public static function ecc_update_cookie_db_version( $version = null ) {
		update_option( 'wt_ecc_cookie_db_version', is_null( $version ) ? '1.0' : $version );
	}
	public static function ecc_get_cookie_db_version() {
		return get_option( 'wt_ecc_cookie_db_version', false );
	}
}
Evdpl_Cookie_Consent_Activator::init();